@@ -1,29 +1,38 @@
 #'
 #' Download and load LODES data into a data frame (tibble)
 #'
-#' @param state US state abbreviation in lower case, can be a vector of states.
-#' @param year year of the lodes data, can be a vector of years.
-#' @param lodes_type table type, values can be origin-destination ("od"), 
-#'   residential association ("rac"), or workplace association ("wac"). od 
-#'   files give a home and destination census block for workers. Residential 
+#' @param state US state abbreviation in lower case, as character. 
+#'   Can be a vector of states, like c("or","md","tx") for Oregon, Maryland, 
+#'   and Texas.
+#' @param year Year of the lodes data, as numerical.
+#'   Can be a vector of years, like c(2014, 2020) for 2014 and 2020.
+#' @param version The LODES version to use.  
+#'   Version 8 (the default, use "LODES8") is enumerated at 2020 Census blocks. 
+#'   "LODES7" is enumerated at 2010 Census blocks, but ends in 2019; 
+#'   LODES5" is enumerated at 2000 Census blocks, but ends in 2009.  
+#' @param lodes_type The LODES table type.
+#'   Values can be the default origin-destination ("od"),residential association
+#'   ("rac"), or workplace association ("wac"). 
+#'   od files give a home and destination census block for workers. Residential 
 #'   files give job totals of worker home census blocks and workplace files 
 #'   give job totals of worker job census blocks
 #' @param job_type Jobtype: "JT00" for all jobs, "JT01" for Primary Jobs, 
 #'   "JT02" for All Private Jobs, "JT03" for Private Primary jobs, "JT04" for
 #'   All Federal jobs, "JT05" for Federal Primary jobs
-#' @param segment Segment of the workforce: "S000" total number of jobs for
-#'   workers, "SA01" number of jobs for workers aged 29 or younger, "SA02" number
-#'   of jobs for workers aged 30-54,"SA03" number of jobs for workers 55 and
-#'   older, "SE01" number of jobs with earnings $1,250/month or less, "SE02"
-#'   number of jobs with earnings $1,251 to $3,333/month, "SE03" number of jobs
-#'   with earnings greater than $3,333/month, "SI01" number of jobs in Goods
-#'   Producing industry sectors, "SI02" number of jobs in Trade, 
-#'   Transportation, and Utilities industry sectors, "SI03" number of jobs in 
-#'   All Other Services industry sectors
-#' @param state_part Part of the state file, can have values of "main" or "aux"
-#'   in OD files. Using "main" includes workers with their workplace and
-#'   residence in the state. Using "aux" includes workers with residences out 
-#'   of state and workplace in the state of interest
+#' @param segment Segment of the workforce.
+#'   "S000" total number of jobs for workers, "SA01" number of jobs for workers 
+#'   aged 29 or younger, "SA02" number of jobs for workers aged 30-54,"SA03" 
+#'   number of jobs for workers 55 and older, "SE01" number of jobs with 
+#'   earnings $1,250/month or less, "SE02" number of jobs with earnings $1,251 
+#'   to $3,333/month, "SE03" number of jobs with earnings greater than 
+#'   $3,333/month, "SI01" number of jobs in Goods Producing industry sectors, 
+#'   "SI02" number of jobs in Trade, Transportation, & Utilities industry 
+#'   sectors, "SI03" number of jobs in All Other Services industry sectors.
+#' @param state_part Part of the state file, required for "od" lodes_type.  
+#'   Can have values of "main" or "aux" in OD files. Using "main" includes 
+#'   workers with their workplace and residence in the state. Using "aux" 
+#'   includes workers with residences out of state and workplace in the state 
+#'   of interest
 #' @param agg_geo Aggregate to a geography other than Census Block (default). 
 #'   Values can be "bg" for block group, "tract", "county", or "state".
 #' @param download_dir Directory where lodes table will be downloaded.
@@ -64,6 +73,7 @@
 #' }                         
 #' @export
 grab_lodes <- function(state, year, 
+                       version = c("LODES8", "LODES7", "LODES5"),
                        lodes_type = c("od", "rac", "wac"),
                        job_type = c("JT00", "JT01", "JT02", "JT03", "JT04", "JT05"), 
                        segment = c("S000", "SA01", "SA02", "SA03", "SE01", "SE02",
@@ -77,6 +87,7 @@ grab_lodes <- function(state, year,
     ## Handle multiple states x years
     state_year <- expand.grid(state=state, year=year)
     results <- apply(state_year, 1, function(df_row) grab_lodes(df_row[1], df_row[2], 
+                                                           version = version,
                                                            lodes_type = lodes_type,
                                                            job_type = job_type,
                                                            segment = segment,
@@ -91,11 +102,12 @@ grab_lodes <- function(state, year,
   state <- tolower(state)
   
   # Handle errors and set default arguments
-  lodes_type <- match.arg(tolower(lodes_type), c(NULL, "od", "rac", "wac"))
-  agg_geo_to <- match.arg(tolower(agg_geo), c(NULL, "block", "bg", "tract", "county", "state"))
-  job_type <- match.arg(job_type, c(NULL, "JT00", "JT01", "JT02", "JT03", "JT04", "JT05"))
-  segment <- match.arg(segment, c(NULL, "S000", "SA01", "SA02", "SA03", "SE01", "SE02","SE03", "SI01", "SI02", "SI03"))
-  state_part <- match.arg(state_part, c("","main","aux"))
+  version <- rlang::arg_match(version)
+  lodes_type <- rlang::arg_match(lodes_type)
+  agg_geo_to <- rlang::arg_match(agg_geo)
+  job_type <- rlang::arg_match(job_type)
+  segment <- rlang::arg_match(segment)
+  state_part <- rlang::arg_match(state_part)
   
   # Only proceed if use_cache is boolean
   if(!is.logical(use_cache)) { stop("The use_cache paramater must be either TRUE or FALSE") }
@@ -113,14 +125,14 @@ grab_lodes <- function(state, year,
   # Read LODES_types and set col_types
   if (lodes_type == "od") {
     # Set url for od
-    url <- glue::glue("https://lehd.ces.census.gov/data/lodes/LODES7/{state}/{lodes_type}/{state}_{lodes_type}_{state_part}_{job_type}_{year}.csv.gz")
+    url <- glue::glue("https://lehd.ces.census.gov/data/lodes/{version}/{state}/{lodes_type}/{state}_{lodes_type}_{state_part}_{job_type}_{year}.csv.gz")
     # Set column types for od
     col_types <- cols(w_geocode = col_character(), 
                       h_geocode = col_character(),
                       createdate = col_character())
   } else {
     # Set url for rac/wac
-    url <- glue::glue("https://lehd.ces.census.gov/data/lodes/LODES7/{state}/{lodes_type}/{state}_{lodes_type}_{segment}_{job_type}_{year}.csv.gz")    
+    url <- glue::glue("https://lehd.ces.census.gov/data/lodes/{version}/{state}/{lodes_type}/{state}_{lodes_type}_{segment}_{job_type}_{year}.csv.gz")    
 
     # Set column types for rac/wac -- h_ is home, w_ is work (from LODES)
     if (lodes_type == "rac") {
@@ -136,7 +148,7 @@ grab_lodes <- function(state, year,
   httr::stop_for_status(httr::HEAD(url),
     paste("retrieve data for this combination of state and year on LODES.",
           "Please see the most recent LEHD Technical Document for a list of available state/year.",
-          "https://lehd.ces.census.gov/data/lodes/LODES7/"
+          glue::glue("https://lehd.ces.census.gov/data/lodes/{version}/")
     )
   )
   
